Estim_param<-function(X,scale=F,S,method="Regularized",threshold=10^(-6)){
# PURPOSE: estimate the parameters phi and sigma of a PCA model
# from an incomplete or a complete data set 
  if(sum(is.na(X))>0){
# with missing values
    missing <- which(is.na(X))
    impute.data <- imputePCA(X, scale = scale, ncp = S, method = method, 
	threshold = threshold)$completeObs
    reference <- PCA(impute.data, scale.unit = scale, graph = FALSE, 
	ncp = S)
    rec <- reconst(reference, S)
    rec.pca <- as.matrix(X)
    rec.pca[missing] <- rec[missing]
    sd_resid <- apply(impute.data, 2, sd)
  resid <- rec.pca - rec
  if (scale){resid <- sweep(resid, 2, sd_resid, FUN = "/")}
  sigma <- sqrt((sum((resid[-missing])^2))/(nrow(X) * ncol(X) - (length(missing) + ncol(X) + S * (nrow(X) - 1 + ncol(X) - S))))
  }else{
# without missing values
    reference <- PCA(X, scale.unit = scale, graph = FALSE, ncp = S)
    rec <- reconst(reference,ncp=S)
    rec.pca <- as.matrix(X)
    sd_resid <- apply(X, 2, sd)
    resid <- rec.pca - rec
    if (scale){resid <- sweep(resid, 2, sd_resid, FUN = "/")}
    sigma <- sqrt((sum((resid)^2))/(nrow(X) * ncol(X) - (ncol(X) + S * (nrow(X) - 1 + ncol(X) - S))))
  }
  phi<-diag(c((reference$eig[1:S,1]-sigma^2)/reference$eig[1:S,1],rep(0,min(nrow(X)-1,ncol(X))-S)))
  estimation<-list(sigma=sigma,phi=phi)
  return(estimation)
}
